<?php
/**
 * Popup Box Module Pro
 * 
 * @author  Cuispi
 * @version 2.0.3
 * @license Commercial License
 * @package admin
 * @subpackage  admin.controller.module
 */
class ControllerModulePopupBox extends Controller {

  /**
   * Development Mode
   *
   * @var boolean True or false
   */
  private $dev = false;  

  /**
   * List of validation errors.
   *
   * @var array
   */
	private $error = array();

  /**
   * Code name of this module.
   *
   * @var string
   */  
  protected $code;
  
  /**
   * The partial path to the module directory.
   *
   * @var string
   */  
  protected $module_path;
  
  /**
   * The instantiated model class name of this extension.
   *
   * @var string
   */  
  protected $model_name;

  /**
   * Hold an error message regarding the extension core library initialization.
   *
   * @var mixed String or false  Defaults to false.
   */  
  protected $error_lib_init_failed = false;
  
  /**
   * Variable for the Logger class instance.
   *
   * @var object
   */
  protected $logger;

  /**
   * Constructor.
   *
   * @param object $registry
   * @return void
   */
	public function __construct($registry) {
    parent::__construct($registry);

    // Get module code
    $className = strtolower(preg_replace('/(?<=\\w)([A-Z])/', '_\\1', __CLASS__));
    
    if (strpos($className, '_module_') !== false) {
      list(, $code) = explode('_module_', $className);
    } else {
      $code = null;
    }
    
    $this->code = $code;
    
    if (version_compare(VERSION, '2.3.0.0', '<')) { // for OpenCart 2.2.0.0 or earlier.
      $this->module_path = 'module/' . $this->code;
      $this->model_name = 'model_module_' . $this->code;
    } else {
      $this->module_path = 'extension/module/' . $this->code;
      $this->model_name = 'model_extension_module_' . $this->code;
    }    
    
    // Logger
    $this->logger = new Log($this->code . '.log');
	}
  
  /**
   * index method
   *
   * @param void
   * @return void
   */     
	public function index() {

		$this->load->language($this->module_path);
    
    try {
      if (!class_exists('PopupBoxBase')) {
        throw new Exception($this->language->get('error_lib_init_failed')); 
      }      
    }
    catch (Exception $e) {
      $this->logger->write('The class PopupBoxBase does not exist in ' . __FILE__ . ' line ' . __LINE__ . ': ' . $e->getMessage());
      $this->error_lib_init_failed = $e->getMessage();
    }
    
		$this->document->setTitle($this->language->get('heading_title'));
		
		$this->load->model('extension/module');

    // Bootstrap Switch
    $this->document->addScript('view/javascript/' . $this->code . '/bootstrap-switch/3.3.2/js/bootstrap-switch.min.js');
    $this->document->addStyle('view/javascript/' . $this->code . '/bootstrap-switch/3.3.2/css/bootstrap-switch.min.css');
    
    // jQuery UI (JS)
    $this->document->addScript('view/javascript/' . $this->code . '/jquery-ui/1.11.4/ui/core.js');
    $this->document->addScript('view/javascript/' . $this->code . '/jquery-ui/1.11.4/ui/widget.js');
    $this->document->addScript('view/javascript/' . $this->code . '/jquery-ui/1.11.4/ui/mouse.js');
    $this->document->addScript('view/javascript/' . $this->code . '/jquery-ui/1.11.4/ui/position.js'); 
    $this->document->addScript('view/javascript/' . $this->code . '/jquery-ui/1.11.4/ui/menu.js');
    $this->document->addScript('view/javascript/' . $this->code . '/jquery-ui/1.11.4/ui/autocomplete.js');
    $this->document->addScript('view/javascript/' . $this->code . '/jquery-ui/1.11.4/ui/sortable.js');
    $this->document->addScript('view/javascript/' . $this->code . '/jquery-ui/1.11.4/ui/resizable.js');
    
    // jQuery UI (CSS)
    $this->document->addStyle('view/javascript/' . $this->code . '/jquery-ui/1.11.4/themes/base/core.css');
    $this->document->addStyle('view/javascript/' . $this->code . '/jquery-ui/1.11.4/themes/base/autocomplete.css');
    $this->document->addStyle('view/javascript/' . $this->code . '/jquery-ui/1.11.4/themes/base/sortable.css');
    $this->document->addStyle('view/javascript/' . $this->code . '/jquery-ui/1.11.4/themes/base/resizable.css');
    $this->document->addStyle('view/javascript/' . $this->code . '/jquery-ui/1.11.4/themes/base/menu.css');
    $this->document->addStyle('view/javascript/' . $this->code . '/jquery-ui/1.11.4/themes/base/theme.css');
    
    // CodeMirror (JS)
    $this->document->addScript('view/javascript/' . $this->code . '/codemirror/5.19.0/lib/codemirror.js');
    $this->document->addScript('view/javascript/' . $this->code . '/codemirror/5.19.0/addon/edit/matchbrackets.js');
    $this->document->addScript('view/javascript/' . $this->code . '/codemirror/5.19.0/addon/edit/matchtags.js');
    $this->document->addScript('view/javascript/' . $this->code . '/codemirror/5.19.0/addon/fold/xml-fold.js');
    $this->document->addScript('view/javascript/' . $this->code . '/codemirror/5.19.0/addon/hint/show-hint.js');
    $this->document->addScript('view/javascript/' . $this->code . '/codemirror/5.19.0/addon/hint/xml-hint.js');
    $this->document->addScript('view/javascript/' . $this->code . '/codemirror/5.19.0/addon/hint/html-hint.js');
    $this->document->addScript('view/javascript/' . $this->code . '/codemirror/5.19.0/mode/xml/xml.js');
    $this->document->addScript('view/javascript/' . $this->code . '/codemirror/5.19.0/mode/javascript/javascript.js');
    $this->document->addScript('view/javascript/' . $this->code . '/codemirror/5.19.0/mode/css/css.js');
    $this->document->addScript('view/javascript/' . $this->code . '/codemirror/5.19.0/mode/htmlmixed/htmlmixed.js');
    $this->document->addScript('view/javascript/' . $this->code . '/codemirror/5.19.0/mode/clike/clike.js');
    $this->document->addScript('view/javascript/' . $this->code . '/codemirror/5.19.0/mode/php/php.js');
    
    // CodeMirror (CSS)
    $this->document->addStyle('view/javascript/' . $this->code . '/codemirror/5.19.0/lib/codemirror.css');
    $this->document->addStyle('view/javascript/' . $this->code . '/codemirror/5.19.0/addon/hint/show-hint.css'); 
    
    // Bootstrap Colorpicker
    $this->document->addStyle('view/javascript/' . $this->code . '/bootstrap-colorpicker/2.3.3/css/bootstrap-colorpicker.min.css');    
    $this->document->addScript('view/javascript/' . $this->code . '/bootstrap-colorpicker/2.3.3/js/bootstrap-colorpicker.min.js');    
    
    // Summernote
    $this->document->addStyle('view/javascript/summernote/summernote.css');    
    $this->document->addScript('view/javascript/summernote/summernote.js');
    
    if (is_file(DIR_APPLICATION . 'view/stylesheet/' . $this->code . '/' . $this->code . '_summernote.css')) {
      $this->document->addStyle('view/stylesheet/' . $this->code . '/' . $this->code . '_summernote.css');
    }  
    
    // Misc
    $this->document->addScript('view/javascript/' . $this->code . '/jquery.ba-resize.min.js');
    $this->document->addScript('view/javascript/' . $this->code . '/jquery.kh-cookie.min.js');
    
    // Main JS
    $this->document->addStyle('view/stylesheet/' . $this->code . '/' . $this->code . '.css');
    $this->document->addScript('view/javascript/' . $this->code . '/' . $this->code . (!$this->dev ? '.min' : '') . '.js' . ($this->dev ? '?'.  time() : ''));
    
    
    $this->load->model($this->module_path); 
    
    
		if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validate()) {
      
      $submission_type = $this->request->post['submission_type'];
      unset($this->request->post['submission_type']);      

      // Set the version of this extension..
      $this->request->post['config'][$this->code . '_version'] = PopupBox::version(); 
      
      // Save config data.
			$this->load->model('setting/setting');
			$this->model_setting_setting->editSetting($this->code, $this->request->post['config']);
      unset($this->request->post['config']);
      
      // Get the template value for the selected skin.
      $skin_template = '';
        
      if ($this->request->post[$this->code]['skin']) {
        $handle = @fopen(DIR_CATALOG . 'view/theme/default/stylesheet/popup_box/skins/' . strtolower(trim($this->request->post[$this->code]['skin']))  . '.css', 'r');

        if ($handle) {
          while (!feof($handle)) {
            $buffer = fgets($handle);

            if (strpos($buffer, '@template') !== false) {
              $skin_template = strtolower(preg_replace('/^\s+\*\s+@template\s+/', '', str_replace(array("\r", "\n"), '', $buffer)));
            }

            if ($skin_template) {
              break;
            }
          }

          fclose($handle);
        }
      }
      
      $this->request->post[$this->code]['skin_template'] = $skin_template;
      

      // Create a new set of module data or update the existing one..
			if (!isset($this->request->get['module_id'])) {
				$this->model_extension_module->addModule($this->code, $this->request->post[$this->code]);
			} else {
				$this->model_extension_module->editModule($this->request->get['module_id'], $this->request->post[$this->code]);
			}

			$this->session->data['success'] = $this->language->get('text_success');

      
      // The following line decides if it is a "Save" or "Save and close"
      $url = '';

      // Submit form and stay on same page
      if ($submission_type == 'save') {
        if (!isset($this->request->get['module_id'])) { // New entry
          $last_inserted_module_id = $this->{$this->model_name}->getLastInsertedModuleIdByCode($this->code);
          $url = $this->url->link($this->module_path, 'token=' . $this->session->data['token']. '&module_id=' . $last_inserted_module_id, true);
        } else {
          $url = $this->url->link($this->module_path, 'token=' . $this->session->data['token']. '&module_id=' . $this->request->get['module_id'], true);
        }
      } elseif ($submission_type == 'save-and-close') {
        if (version_compare(VERSION, '2.3.0.0', '<')) { // OpenCart 2.2.0.0 or earlier.
          $url = $this->url->link('extension/module', 'token=' . $this->session->data['token'], true);
        } else { // OpenCart 2.3.0.0 or later.
          $url = $this->url->link('extension/extension', 'token=' . $this->session->data['token'] . '&type=module', true);
        }        
      }     
      
      $this->response->redirect($url);
		}
 
    
    $data = array();
 
    
    // Heading
		$data['heading_title'] = $this->language->get('heading_title');  

    // Version
    if (!$this->error_lib_init_failed) {
      $data['version'] = PopupBox::version();
    } else {
      $data['version'] = false;
    }
    
    // Text
		$data['text_edit'] = $this->language->get('text_edit');
		$data['text_new'] = $this->language->get('text_new');
		$data['text_enabled'] = $this->language->get('text_enabled');
		$data['text_disabled'] = $this->language->get('text_disabled');
		$data['text_general'] = $this->language->get('text_general');
		$data['text_editor'] = $this->language->get('text_editor');
		$data['text_hide_on_selected_pages'] = $this->language->get('text_hide_on_selected_pages');
		$data['text_show_on_selected_pages'] = $this->language->get('text_show_on_selected_pages');
		$data['text_check_all'] = $this->language->get('text_check_all');
		$data['text_uncheck_all'] = $this->language->get('text_uncheck_all');
		$data['text_guest_users'] = $this->language->get('text_guest_users');
		$data['text_confirm_delete'] = $this->language->get('text_confirm_delete');
		$data['text_confirm_changes_will_be_lost'] = $this->language->get('text_confirm_changes_will_be_lost');
		$data['text_on'] = $this->language->get('text_on');
		$data['text_off'] = $this->language->get('text_off');
		$data['text_seconds'] = $this->language->get('text_seconds');
		$data['text_minutes'] = $this->language->get('text_minutes');
		$data['text_percent_sign'] = $this->language->get('text_percent_sign');
		$data['text_px'] = $this->language->get('text_px');
		$data['text_url'] = $this->language->get('text_url');
		$data['text_link_target_self'] = $this->language->get('text_link_target_self');
		$data['text_link_target_blank'] = $this->language->get('text_link_target_blank');
    $data['text_http_get'] = $this->language->get('text_http_get');
    $data['text_http_post'] = $this->language->get('text_http_post');
    $data['text_default_skin'] = $this->language->get('text_default_skin');
    $data['text_bg_filter_blur'] = $this->language->get('text_bg_filter_blur');
    $data['text_bg_filter_heavy_blur'] = $this->language->get('text_bg_filter_heavy_blur');
    $data['text_bg_filter_gray_mono'] = $this->language->get('text_bg_filter_gray_mono');
    $data['text_bg_filter_gray_mono_with_blur'] = $this->language->get('text_bg_filter_gray_mono_with_blur');
    $data['text_bg_filter_gray_mono_with_heavy_blur'] = $this->language->get('text_bg_filter_gray_mono_with_heavy_blur');
    $data['text_bg_filter_sepia'] = $this->language->get('text_bg_filter_sepia');
    $data['text_bg_filter_translucent'] = $this->language->get('text_bg_filter_translucent');
    $data['text_display_click'] = $this->language->get('text_display_click');
    $data['text_display_delay'] = $this->language->get('text_display_delay');
    $data['text_display_mouseleave'] = $this->language->get('text_display_mouseleave');
    $data['text_display_none'] = $this->language->get('text_display_none');
    $data['text_display_scroll'] = $this->language->get('text_display_scroll');
    $data['text_display_scroll_2'] = $this->language->get('text_display_scroll_2');
    $data['text_expires_after'] = $this->language->get('text_expires_after');
    $data['text_on_confirm_click_close_modal'] = $this->language->get('text_on_confirm_click_close_modal');
    $data['text_on_confirm_click_open_link'] = $this->language->get('text_on_confirm_click_open_link');
    $data['text_on_confirm_click_print'] = $this->language->get('text_on_confirm_click_print');
    $data['text_on_confirm_click_submit_form'] = $this->language->get('text_on_confirm_click_submit_form');
    $data['text_on_confirm_click_run_js'] = $this->language->get('text_on_confirm_click_run_js');
    $data['text_on_cancel_click_close_modal'] = $this->language->get('text_on_cancel_click_close_modal');
    $data['text_on_cancel_click_open_link'] = $this->language->get('text_on_cancel_click_open_link');
    $data['text_on_cancel_click_print'] = $this->language->get('text_on_cancel_click_print');
    $data['text_on_cancel_click_submit_form'] = $this->language->get('text_on_cancel_click_submit_form');
    $data['text_on_cancel_click_run_js'] = $this->language->get('text_on_cancel_click_run_js');
    $data['text_login_status_always'] = $this->language->get('text_login_status_always');
    $data['text_login_status_show'] = $this->language->get('text_login_status_show');
    $data['text_login_status_hide'] = $this->language->get('text_login_status_hide');
    $data['text_template_include_code_shown_later'] = $this->language->get('text_template_include_code_shown_later');
    $data['text_heading_general'] = $this->language->get('text_heading_general');
    $data['text_heading_appearance'] = $this->language->get('text_heading_appearance');
    $data['text_heading_behavior'] = $this->language->get('text_heading_behavior');
    $data['text_heading_display_conditions'] = $this->language->get('text_heading_display_conditions');
    $data['text_heading_template'] = $this->language->get('text_heading_template');
    $data['text_heading_scripts_and_styles'] = $this->language->get('text_heading_scripts_and_styles');
    $data['text_heading_misc'] = $this->language->get('text_heading_misc'); 
    $data['text_anim_effect_default'] = $this->language->get('text_anim_effect_default');
    $data['text_anim_effect_fade'] = $this->language->get('text_anim_effect_fade');
    $data['text_anim_effect_zoom_in'] = $this->language->get('text_anim_effect_zoom_in');
    $data['text_anim_effect_zoom_out'] = $this->language->get('text_anim_effect_zoom_out');
    $data['text_anim_effect_slide_in_top'] = $this->language->get('text_anim_effect_slide_in_top');
    $data['text_anim_effect_slide_in_bottom'] = $this->language->get('text_anim_effect_slide_in_bottom');
    $data['text_anim_effect_slide_in_right'] = $this->language->get('text_anim_effect_slide_in_right');
    $data['text_anim_effect_slide_in_left'] = $this->language->get('text_anim_effect_slide_in_left');
    $data['text_anim_effect_sticky_up'] = $this->language->get('text_anim_effect_sticky_up');
    $data['text_anim_effect_sticky_down'] = $this->language->get('text_anim_effect_sticky_down');
    $data['text_anim_effect_newspaper'] = $this->language->get('text_anim_effect_newspaper');
    $data['text_anim_effect_3d_slit'] = $this->language->get('text_anim_effect_3d_slit');
    $data['text_anim_effect_3d_flip_horiz'] = $this->language->get('text_anim_effect_3d_flip_horiz');     
    $data['text_show_sharethis_social_channels'] = $this->language->get('text_show_sharethis_social_channels');    
    $data['text_hide_sharethis_social_channels'] = $this->language->get('text_hide_sharethis_social_channels');    
    
    // Entry
		$data['entry_name'] = $this->language->get('entry_name');
		$data['entry_status'] = $this->language->get('entry_status');
		$data['entry_show_title'] = $this->language->get('entry_show_title');
		$data['entry_title'] = $this->language->get('entry_title');
		$data['entry_title_link'] = $this->language->get('entry_title_link');
		$data['entry_use_form'] = $this->language->get('entry_use_form');
		$data['entry_form_action'] = $this->language->get('entry_form_action');
		$data['entry_form_method'] = $this->language->get('entry_form_method');
		$data['entry_html_content'] = $this->language->get('entry_html_content');
		$data['entry_dont_show_me_link'] = $this->language->get('entry_dont_show_me_link');    
		$data['entry_show_dont_show_me'] = $this->language->get('entry_show_dont_show_me');    
		$data['entry_dont_show_me_text'] = $this->language->get('entry_dont_show_me_text');   
		$data['entry_confirm_btn'] = $this->language->get('entry_confirm_btn');
		$data['entry_show_confirm_btn'] = $this->language->get('entry_show_confirm_btn');
		$data['entry_confirm_btn_text'] = $this->language->get('entry_confirm_btn_text');
		$data['entry_cancel_btn'] = $this->language->get('entry_cancel_btn');
		$data['entry_show_cancel_btn'] = $this->language->get('entry_show_cancel_btn');
		$data['entry_cancel_btn_text'] = $this->language->get('entry_cancel_btn_text');
		$data['entry_close_btn'] = $this->language->get('entry_close_btn');
		$data['entry_show_close_btn'] = $this->language->get('entry_show_close_btn');
		$data['entry_modal_size'] = $this->language->get('entry_modal_size');
		$data['entry_modal_max_width'] = $this->language->get('entry_modal_max_width');
		$data['entry_modal_max_height'] = $this->language->get('entry_modal_max_height');
		$data['entry_anim_effect'] = $this->language->get('entry_anim_effect');    
		$data['entry_skin'] = $this->language->get('entry_skin');
		$data['entry_overlay'] = $this->language->get('entry_overlay');
		$data['entry_use_overlay_color'] = $this->language->get('entry_use_overlay_color');
		$data['entry_overlay_color'] = $this->language->get('entry_overlay_color');
		$data['entry_overlay_opacity'] = $this->language->get('entry_overlay_opacity');
		$data['entry_background'] = $this->language->get('entry_background');
		$data['entry_add_bg_layer'] = $this->language->get('entry_add_bg_layer');
		$data['entry_bg_filter'] = $this->language->get('entry_bg_filter');
		$data['entry_display'] = $this->language->get('entry_display');  
		$data['entry_additional_dont_show_me_options'] = $this->language->get('entry_additional_dont_show_me_options');    
		$data['entry_dont_show_me_on_close'] = $this->language->get('entry_dont_show_me_on_close');
		$data['entry_dont_show_me_on_escape'] = $this->language->get('entry_dont_show_me_on_escape');
		$data['entry_dont_show_me_on_cancel'] = $this->language->get('entry_dont_show_me_on_cancel');
		$data['entry_dont_show_me_on_confirm'] = $this->language->get('entry_dont_show_me_on_confirm');
		$data['entry_dont_show_me_on_outside_click'] = $this->language->get('entry_dont_show_me_on_outside_click');
		$data['entry_expires_after'] = $this->language->get('entry_expires_after');      
		$data['entry_additional_closing_options'] = $this->language->get('entry_additional_closing_options');      
		$data['entry_close_on_outside_click'] = $this->language->get('entry_close_on_outside_click');
		$data['entry_close_on_escape'] = $this->language->get('entry_close_on_escape');
		$data['entry_on_confirm_click'] = $this->language->get('entry_on_confirm_click');
		$data['entry_on_cancel_click'] = $this->language->get('entry_on_cancel_click');
		$data['entry_before_initialization_callback'] = $this->language->get('entry_before_initialization_callback');
		$data['entry_use_before_initialize'] = $this->language->get('entry_use_before_initialize');
		$data['entry_after_initialization_callback'] = $this->language->get('entry_after_initialization_callback');
		$data['entry_use_after_initialize'] = $this->language->get('entry_use_after_initialize');
		$data['entry_hash_tracking'] = $this->language->get('entry_hash_tracking');
		$data['entry_use_hash_tracking'] = $this->language->get('entry_use_hash_tracking');
		$data['entry_hash'] = $this->language->get('entry_hash');
		$data['entry_stores'] = $this->language->get('entry_stores');
		$data['entry_customer_groups'] = $this->language->get('entry_customer_groups');
		$data['entry_categories'] = $this->language->get('entry_categories');
		$data['entry_login_status'] = $this->language->get('entry_login_status');
		$data['entry_date_start'] = $this->language->get('entry_date_start');
		$data['entry_date_end'] = $this->language->get('entry_date_end');
		$data['entry_template'] = $this->language->get('entry_template');
		$data['entry_use_custom_template'] = $this->language->get('entry_use_custom_template');
		$data['entry_external_css'] = $this->language->get('entry_external_css');
		$data['entry_external_js'] = $this->language->get('entry_external_js');
		$data['entry_use_default_stylesheet'] = $this->language->get('entry_use_default_stylesheet');
		$data['entry_internal_css'] = $this->language->get('entry_internal_css');
		$data['entry_use_default_javascript'] = $this->language->get('entry_use_default_javascript');
		$data['entry_internal_js'] = $this->language->get('entry_internal_js');
		$data['entry_tracking_code'] = $this->language->get('entry_tracking_code');
		$data['entry_show_sharethis'] = $this->language->get('entry_show_sharethis');
		$data['entry_sharethis_share_buttons'] = $this->language->get('entry_sharethis_share_buttons');
		$data['entry_sharethis_pub_key'] = $this->language->get('entry_sharethis_pub_key');    
		$data['entry_params'] = $this->language->get('entry_params');
    $data['entry_config_status'] = $this->language->get('entry_config_status');
    $data['entry_config_js_debug'] = $this->language->get('entry_config_js_debug');
		$data['entry_config_editor_lang'] = $this->language->get('entry_config_editor_lang');
		$data['entry_config_editor_height'] = $this->language->get('entry_config_editor_height');
		$data['entry_config_editor_tabsize'] = $this->language->get('entry_config_editor_tabsize');
		$data['entry_config_editor_codemirror_theme'] = $this->language->get('entry_config_editor_codemirror_theme');
		$data['entry_template_include_usage'] = $this->language->get('entry_template_include_usage');
    
    // Help
		$data['help_title'] = $this->language->get('help_title');
		$data['help_title_link'] = $this->language->get('help_title_link');
		$data['help_use_form'] = $this->language->get('help_use_form');
		$data['help_expires_after'] = $this->language->get('help_expires_after');
		$data['help_status'] = $this->language->get('help_status');
		$data['help_form_action'] = $this->language->get('help_form_action');
		$data['help_form_method'] = $this->language->get('help_form_method');    
		$data['help_html_content'] = $this->language->get('help_html_content');   
    $data['help_modal_max_width'] = $this->language->get('help_modal_max_width');
    $data['help_modal_max_height'] = $this->language->get('help_modal_max_height');
		$data['help_display_click_selector'] = $this->language->get('help_display_click_selector');
		$data['help_on_confirm_click_submit_form'] = $this->language->get('help_on_confirm_click_submit_form');
		$data['help_on_cancel_click_submit_form'] = $this->language->get('help_on_cancel_click_submit_form');
		$data['help_hash_tracking'] = $this->language->get('help_hash_tracking');
		$data['help_hash'] = $this->language->get('help_hash');
		$data['help_stores'] = $this->language->get('help_stores');
		$data['help_customer_groups'] = $this->language->get('help_customer_groups');
		$data['help_categories'] = $this->language->get('help_categories');
		$data['help_template'] = $this->language->get('help_template');
		$data['help_template_include_usage'] = $this->language->get('help_template_include_usage');
		$data['help_external_css'] = $this->language->get('help_external_css');
		$data['help_use_default_stylesheet'] = $this->language->get('help_use_default_stylesheet');
		$data['help_external_js'] = $this->language->get('help_external_js');
		$data['help_use_default_javascript'] = $this->language->get('help_use_default_javascript');
		$data['help_internal_css'] = $this->language->get('help_internal_css');
		$data['help_internal_js'] = $this->language->get('help_internal_js');
		$data['help_tracking_code'] = $this->language->get('help_tracking_code');
		$data['help_sharethis_share_buttons'] = $this->language->get('help_sharethis_share_buttons');
		$data['help_sharethis_pub_key'] = $this->language->get('help_sharethis_pub_key');		
		$data['help_params'] = $this->language->get('help_params');
		$data['help_config_status'] = $this->language->get('help_config_status');   
		$data['help_config_js_debug'] = $this->language->get('help_config_js_debug');   
    
    // Tab
    $data['tab_popup_box'] = $this->language->get('tab_popup_box');
    $data['tab_config'] = $this->language->get('tab_config');
		$data['tab_layouts'] = $this->language->get('tab_layouts');
		$data['tab_help'] = $this->language->get('tab_help');
    
    // Button
    $data['button_add_new'] = $this->language->get('button_add_new');
		$data['button_save'] = $this->language->get('button_save');
		$data['button_cancel'] = $this->language->get('button_cancel');
		$data['button_save_and_close'] = $this->language->get('button_save_and_close');
    
    
		if (isset($this->error['warning'])) {
			$data['error_warning'] = $this->error['warning'];
		} else {
			$data['error_warning'] = '';
		}
		
		if (isset($this->error['name'])) {
			$data['error_name'] = $this->error['name'];
		} else {
			$data['error_name'] = '';
		}
    
		if (isset($this->error['modal_max_width'])) {
			$data['error_modal_max_width'] = $this->error['modal_max_width'];
		} else {
			$data['error_modal_max_width'] = '';
		}
		
		if (isset($this->error['modal_max_height'])) {
			$data['error_modal_max_height'] = $this->error['modal_max_height'];
		} else {
			$data['error_modal_max_height'] = '';
		} 
    
    if ($this->error_lib_init_failed) {
      $data['error_lib_init_failed'] = $this->error_lib_init_failed;
    } else {
      $data['error_lib_init_failed'] = false;
    }    
    
    // Breadcrumbs
		$data['breadcrumbs'] = array();

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('text_home'),
			'href' => $this->url->link('common/dashboard', 'token=' . $this->session->data['token'], true)
		);

    if (version_compare(VERSION, '2.3.0.0', '<')) { // OpenCart 2.2.0.0 or earlier.
      $data['breadcrumbs'][] = array(
        'text' => $this->language->get('text_module'),
        'href' => $this->url->link('extension/module', 'token=' . $this->session->data['token'], true)
      );
    } else { // OpenCart 2.3.0.0 or later.
      $data['breadcrumbs'][] = array(
        'text' => $this->language->get('text_extension'),
        'href' => $this->url->link('extension/extension', 'token=' . $this->session->data['token'] . '&type=module', true)
      );    
    }    

		if (!isset($this->request->get['module_id'])) {
			$data['breadcrumbs'][] = array(
				'text' => $this->language->get('heading_title'),
				'href' => $this->url->link($this->module_path, 'token=' . $this->session->data['token'], true)
			);
		} else {
			$data['breadcrumbs'][] = array(
				'text' => $this->language->get('heading_title'),
				'href' => $this->url->link($this->module_path, 'token=' . $this->session->data['token'] . '&module_id=' . $this->request->get['module_id'], true)
			);			
		}

		if (!isset($this->request->get['module_id'])) {
			$data['action'] = $this->url->link($this->module_path, 'token=' . $this->session->data['token'], true);
		} else {
			$data['action'] = $this->url->link($this->module_path, 'token=' . $this->session->data['token'] . '&module_id=' . $this->request->get['module_id'], true);
		}
		
    if (version_compare(VERSION, '2.3.0.0', '<')) { // OpenCart 2.2.0.0 or earlier.
      $data['cancel'] = $this->url->link('extension/module', 'token=' . $this->session->data['token'], true);
    } else {
      $data['cancel'] = $this->url->link('extension/extension', 'token=' . $this->session->data['token'] . '&type=module', true);
    }

    // Module id
    if (isset($this->request->get['module_id']) && $this->request->get['module_id']) {
      $data['module_id'] = (int) $this->request->get['module_id'];
    } else {
      $data['module_id'] = null;
    }
    
    // Token
		$data['token'] = $this->session->data['token'];

    //
    // Languages
    // --------------------------------------------------      

    $this->load->model('localisation/language');
    
    $languages = $this->model_localisation_language->getLanguages();
    
    $data['languages'] = $languages;
    $data['primary_language'] = reset($languages);

    //
    // Stores
    // --------------------------------------------------       

		$this->load->model('setting/store');
    
		$data['stores'] = array();
		
    $data['stores'][] = array(
			'store_id' => 0,
			'name' => $this->config->get('config_name')
		);
		
    $stores = array_merge($data['stores'], $this->model_setting_store->getStores());    
		$data['stores'] = $stores;
    
    //
    // Customer groups for access levels
    // --------------------------------------------------  

    if ($this->isOC2031orEarlier()) { // for OpenCart 2.0.3.1 or earlier.
      $this->load->model('sale/customer_group');
      $customer_groups = $this->model_sale_customer_group->getCustomerGroups();
      
    } else { // for OpenCart 2.1.0.0 or later.
      $this->load->model('customer/customer_group');
      $customer_groups = $this->model_customer_customer_group->getCustomerGroups();
    }    

    foreach ($customer_groups as $key => $customer_group) {
      if ($customer_group['customer_group_id'] == $this->config->get('config_customer_group_id')) {
        $customer_groups[$key]['name'] = $customer_group['name'] . ' ' . $this->language->get('text_default');
        $customer_groups[$key]['customer_group_default'] = 1;
        
      } else {
        $customer_groups[$key]['customer_group_default'] = 0;
      }
    }

    $formatted_customer_groups = array_merge(array(array(
        'customer_group_id' => 0,
        'name' => $this->language->get('text_guest_users'),
        'customer_group_default' => 0
    )), $customer_groups);
    
    $data['customer_groups'] = $formatted_customer_groups;
    
    //
    // Categories
    // --------------------------------------------------      

    $this->load->model('catalog/category');
    
    $data['categories'] = $this->model_catalog_category->getCategories(array('sort' => 'name', 'order' => 'ASC'));

    //
    // Skins
    // --------------------------------------------------
    
    $skins = array();
    
		$skin_css_files = glob(DIR_CATALOG . 'view/theme/default/stylesheet/popup_box/skins/*');
    
		foreach ($skin_css_files as $skin_css_file) {
      $skin_key = strtolower(basename($skin_css_file, '.css'));
      
      $handle = @fopen($skin_css_file, 'r');
      
      if ($handle) {
        $skin_name = null;
        
        while (!feof($handle)) {
          $buffer = fgets($handle);
          
          if (strpos($buffer, '@name') !== false) {
            $skin_name = preg_replace('/^\s+\*\s+@name\s+/', '', str_replace(array("\r", "\n"), '', $buffer));
          }

          if ($skin_name) {
            break;
          }
        }
        
        fclose($handle);
      }

      $skins[] = array(
          'key' => $skin_key,
          'name' => $skin_name
      );
		}
    
    $data['skins'] = $skins;
    
    //
    // Module data
    // --------------------------------------------------     
  
    $module_data = array(
        'name' => '',
        'show_title' => true,
        'title' => array(),
        'title_link' => '',
        'html_content' => '',
        'use_form' => false,
        'form_action' => '',
        'form_method' => 'get',
        'form_name' => '',
        'form_id' => '',
        'form_class' => '',
        'show_dont_show_me' => true,
        'dont_show_me_text' => array(),        
        'show_confirm_btn' => true,
        'confirm_btn_text' => array(),
        'show_cancel_btn' => true,
        'cancel_btn_text' => array(),
        'show_close_btn' => true,
        'status' => false,        
        'modal_max_width' => '600px',
        'modal_max_height' => 'auto',
        'anim_effect' => false,
        'skin' => '',
        'use_overlay_color' => true,
        'overlay_color' => '#000000',
        'overlay_opacity' => 80,
        'add_bg_layer' => false,
        'bg_filter' => '',
        'display' => null,
        'display_delay' => 1,
        'delay_type' => 'sec',
        'display_scroll' => 50,
        'display_click' => '',
        'scroll_type' => '%',
        'dont_show_me_on_close' => false,
        'dont_show_me_on_escape' => false,
        'dont_show_me_on_cancel' => false,
        'dont_show_me_on_confirm' => false,
        'dont_show_me_on_outside_click' => false,
        'expires_after' => null,
        'close_on_outside_click' => true,
        'close_on_escape' => true,
        'on_confirm_click' => null,
        'on_confirm_click_ln_url' => '',
        'on_confirm_click_ln_trg' => '',
        'on_confirm_click_code' => '',
        'on_cancel_click' => null,
        'on_cancel_click_ln_url' => '',
        'on_cancel_click_ln_trg' => '',
        'on_cancel_click_code' => '',
        'use_before_initialize' => false, 
        'before_initialize_code' => '',
        'use_after_initialize' => false, 
        'after_initialize_code' => '',
        'use_hash_tracking' => true,
        'hash' => '',
        'stores' => array(),
        'customer_groups' => array(),
        'on_selected_categories' => array(),
        'categories' => array(),
        'login_status' => null,
        'date_start' => '',
        'date_end' => '',
        'use_custom_template' => false,
        'template' => '',
        'use_default_stylesheet' => true,
        'external_css' => '',
        'internal_css' => '',
        'use_default_javascript' => true,
        'external_js' => '',
        'internal_js' => '',
        'tracking_code' => '',
        'show_sharethis' => false,
        'sharethis_share_buttons' => "facebook: Facebook\r\ntwitter: Twitter\r\ngoogleplus: Google+\r\npinterest: Pinterest\r\nlinkedin: LinkedIn\r\ntumblr: Tumblr\r\npocket: Pocket",
        'sharethis_pub_key' => '',        
        'params' => '',
    );
    
    // Get current module
		if (isset($this->request->get['module_id']) && ($this->request->server['REQUEST_METHOD'] != 'POST')) {
			$module_info = $this->model_extension_module->getModule($this->request->get['module_id']);
		}    
    
		if (count($this->request->post)) {
			$module_data = array_merge($module_data, $this->request->post[$this->code]);
    
    } elseif (isset($this->request->get['module_id']) && empty($module_info)) {
      $this->response->redirect($this->url->link($this->module_path, 'token=' . $this->session->data['token'], true));
      
    } elseif (!empty($module_info)) {
      $module_data = array_merge($module_data, $module_info);
      
		} else { // Perform CREATE operation.
      // Auto-select the default store checkbox in the Stores field.
      $module_data['stores'] = array(0);
      
      // Auto-select the "Guest Users" checkbox in the Customer Groups field.
      $module_data['customer_groups'] = array(0);
    }

    $data[$this->code] = $module_data;
    
    //
    // Config
    // --------------------------------------------------

    $config_data = array(
        $this->code . '_status' => false,
        $this->code . '_config' => array(
            'js_debug' => false,
            'editor' => array(
                'lang' => 'en-US',
                'direction' => 'ltr',
                'height' => 300,
                'tabsize' => 4,
                'codemirror' => array(
                    'theme' => 'monokai'
                )
            ),
        ),
    );
    
    $extension_status = (bool)$this->config->get($this->code . '_status');
    $config_info = (array)$this->config->get($this->code . '_config');

		if (count($this->request->post)) {
			$config_data = array_merge($config_data, $this->request->post['config']);
      
    } elseif (!empty($config_info)) {
      $config_data = array_replace_recursive($config_data, array_merge(array(
          $this->code . '_status' => $extension_status,
          $this->code . '_config' => $config_info
      )));
    }
       
    $data['config'] = $config_data;

    
    // Editor
    $editor_settings = $config_data[$this->code . '_config']['editor'];
    
    if (is_file(DIR_APPLICATION . 'view/javascript/' . $this->code . '/codemirror/5.19.0/theme/' . $editor_settings['codemirror']['theme'] . '.css')) {
      $this->document->addStyle('view/javascript/' . $this->code . '/codemirror/5.19.0/theme/' . $editor_settings['codemirror']['theme'] . '.css');   
    }
    
    // Get codemirror themes for the "Code View Theme" select box.
    $codemirror_themes = array();
    
    $css_files = glob(DIR_APPLICATION . 'view/javascript/' . $this->code . '/codemirror/5.19.0/theme/*');
		
    foreach ($css_files as $css_file) {
      $name = basename($css_file, '.css');
      $codemirror_themes[$name] = ucfirst($name);
		}
    
    $data['codemirror_themes'] = $codemirror_themes;
    unset($codemirror_themes, $css_files, $css_file, $name);
    
    
    // Try to include a summernote language file other than the default.
    if ($editor_settings['lang'] != 'en-US') {
      if (is_file(DIR_APPLICATION . 'view/javascript/summernote/lang/summernote-' . $editor_settings['lang'] . '.js')) {
        $this->document->addScript('view/javascript/summernote/lang/summernote-' . $editor_settings['lang'] . '.js');
      }
    }
    
    // Get summernote languages for the "Editor > Language" select box.
    $summernote_languages = array('en-US' => 'en-US');

    $lang_files = glob(DIR_APPLICATION . 'view/javascript/summernote/lang/*.js');
    
		foreach ($lang_files as $lang_file) {
      $name = str_replace('summernote-', '', basename($lang_file, '.js'));
      $summernote_languages[$name] = $name;
		}
    
    natsort($summernote_languages);
    
    $data['summernote_languages'] = $summernote_languages;
    unset($summernote_languages, $lang_files, $lang_file, $name);
    
    //
    // Misc
    // --------------------------------------------------

    // Links
    $data['to_layouts'] = $this->url->link('design/layout', 'token=' . $this->session->data['token'], true);
    
    // Code
		$data['code'] = $this->code;
    
    // Path
		$data['module_path'] = $this->module_path;
    
    // Set the current module ID.
    if (!isset($this->request->get['module_id'])) {
      $data['current_module_id'] = null;
    } else {
      $data['current_module_id'] = $this->request->get['module_id'];
    }
    
    // Operation mode
    if (!isset($this->request->get['module_id'])) {
      $data['is_new'] = true;
    } else {
      $data['is_new'] = false;
    }
    
    // URL for the Add New button.
    $data['add_new_action'] = $this->url->link($this->module_path, 'token=' . $this->session->data['token'], true);
    
    // Modules
    $modules = $this->model_extension_module->getModulesByCode($this->code);
    
    foreach ($modules as $key => $module) {
      if ($this->isOC2031orEarlier()) { // for OpenCart 2.0.3.1 or earlier.
        $setting = unserialize($module['setting']);
      } else { // for OpenCart 2.1.0.0 or later.
        $setting = json_decode($module['setting'], true);
      }      
      
      $modules[$key]['status'] = (bool)$setting['status'];
      
      $modules[$key]['actions']['edit'] = $this->url->link($this->module_path, 'token=' . $this->session->data['token'] . '&module_id=' . $module['module_id'], true);
      $modules[$key]['actions']['delete'] = $this->url->link($this->module_path . '/delete', 'token=' . $this->session->data['token'] . '&module_id=' . $module['module_id'], true);
    }
    
    unset($setting);
    
    $data['modules'] = $modules;
    

		if (isset($this->request->post['config'][$this->code . '_lic'])) {
			$lic_data = $this->request->post['config'][$this->code . '_lic'];
		} else {
      $lic_data = $this->config->get($this->code . '_lic');
		}
    
    $data['config'][$this->code . '_lic'] = $lic_data;
    
    $data['lic_key'] = $lic_data['key'];
    
    $data['admin_language'] = $this->config->get('config_admin_language');        
    
    //
    // Template
    // --------------------------------------------------       

		$data['header'] = $this->load->controller('common/header');
		$data['column_left'] = $this->load->controller('common/column_left');
		$data['footer'] = $this->load->controller('common/footer');
    
    if (version_compare(VERSION, '2.2.0.0', '<')) { // for OpenCart 2.1.0.2 or earlier.
      $this->response->setOutput($this->load->view($this->module_path . '.tpl', $data));
    } else {
      $this->response->setOutput($this->load->view($this->module_path, $data));    
    }  
	}

  /**
   * Validates requests and authorizations.
   *
   * @param void
   * @return boolean True or false  Returns true if all fields pass validation.
   */  
	protected function validate() {
		if (!$this->user->hasPermission('modify', $this->module_path)) {
			$this->error['warning'] = $this->language->get('error_permission');
		}
		
		if ((utf8_strlen($this->request->post[$this->code]['name']) < 3) || (utf8_strlen($this->request->post[$this->code]['name']) > 64)) {
			$this->error['name'] = $this->language->get('error_name');
		}
		
    // Regular Expression To Validate CSS Length
    // 
    // A valid CSS length value follows a set rules:
    //   * Length can be “auto”
    //   * Has a floating point number with an optional + or – sign.
    //   * The floating point number has a trailing length unit1 or percentage.
    //   * 0 can be specified as length and without unit
    //
    // @link http://www.shamasis.net/2009/07/regular-expression-to-validate-css-length-and-position-values/
    //
    $css_unit_pattern = "/^(auto|0)$|^[+-]?[0-9]+.?([0-9]+)?(px|em|ex|%|in|cm|mm|pt|pc)$/";

    if (!preg_match($css_unit_pattern, $this->request->post[$this->code]['modal_max_width'])) {
			$this->error['modal_max_width'] = $this->language->get('error_modal_max_width');
		}

    if (!preg_match($css_unit_pattern, $this->request->post[$this->code]['modal_max_height'])) {
			$this->error['modal_max_height'] = $this->language->get('error_modal_max_height');
		}
    
		if ($this->error && !isset($this->error['warning'])) {
			$this->error['warning'] = $this->language->get('error_warning');
		}
    
		return !$this->error;
	}
  
  /**
   * Delete a module.
   *
   * @param void
   * @return Redirect or false
   */    
	public function delete() {
		$this->load->model('extension/module');
    
    if (version_compare(VERSION, '2.3.0.0', '<')) { // OpenCart 2.2.0.0 or earlier
      $permission = $this->user->hasPermission('modify', 'extension/module');
    } else { // OpenCart 2.3.0.0 or later
      $permission = $this->user->hasPermission('modify', 'extension/extension/module');
    }
    
		if (isset($this->request->get['module_id']) && $permission) {
			$this->model_extension_module->deleteModule($this->request->get['module_id']);
      
      // Modules
      $modules = $this->model_extension_module->getModulesByCode($this->code);
      
      if ($modules) {
        $url = $this->url->link($this->module_path, 'token=' . $this->session->data['token']. '&module_id=' . $modules[0]['module_id'], true);
      } else {
        if (version_compare(VERSION, '2.3.0.0', '<')) { // OpenCart 2.2.0.0 or earlier.
          $url = $this->url->link('extension/module', 'token=' . $this->session->data['token'], true);
        } else { // OpenCart 2.3.0.0 or later.
          $url = $this->url->link('extension/extension', 'token=' . $this->session->data['token'] . '&type=module', true);
        }          
      }
      
			$this->response->redirect($url);
		}
    
    return false;
	}
  
  /**
   * Checks if OpenCart 2.0.3.1 or earlier
   *
   * @param void
   * @return bool True or false
   */
  protected function isOC2031orEarlier() {
    return version_compare(str_replace('_rc1', '.RC.1', VERSION), '2.1.0.0.RC.1', '<');
  }
  
  /**
   * Save lic data
   *
   * @param void
   * @return JSON data
   */  
	public function save_lic() {
    // Detect an AJAX request.
    if (!(!empty($_SERVER['HTTP_X_REQUESTED_WITH']) && strtolower($_SERVER['HTTP_X_REQUESTED_WITH']) == 'xmlhttprequest')) {
      return false;
    }
    
    $value = array(
        'key' => $this->request->post['key'],
        'licensee' => array(
            'name' => $this->request->post['licensee']['name'],
        ),
        'server' => $this->request->post['server'],
        'purchased_at' => array(
            'raw' => $this->request->post['purchased_at']['raw'],
            'formatted' => $this->request->post['purchased_at']['formatted'],
        ),
        'expires_at' => array(
            'raw' => $this->request->post['expires_at']['raw'],
            'formatted' => $this->request->post['expires_at']['formatted'],
        ),
        'status' => array(
            'id' => $this->request->post['status']['id'],
            'name' => $this->request->post['status']['name'],
            'icon' => array(
                'name' => $this->request->post['status']['icon']['name'],
                'color' => $this->request->post['status']['icon']['color']
            ),
        ),
        'checked_at' => array(
            'raw' => $this->request->post['checked_at']['raw'],
            'formatted' => $this->request->post['checked_at']['formatted'],
        ),
        'urls' => array(
            'list' => $this->request->post['urls']['list'],
            'detail' => $this->request->post['urls']['detail'],
        ),
    );
    
    $this->load->model($this->module_path); 
    $data = $this->{$this->model_name}->updateSettingValue($this->code, $this->code . '_lic', $value);

    if (! $this->isOC2031orEarlier()) { // for OpenCart 2.1.0.0 or later.
      // Convert an object to an array
      $data = json_decode(json_encode($data), true);
    }  

		$this->response->setOutput(json_encode($data));
	}
  
}
