<?php
class ControllerProductCategory extends Controller {
	public function index() {
		$this->load->language('product/category');

		$this->load->model('catalog/category');

		$this->load->model('catalog/product');

		$this->load->model('tool/image');

		if (isset($this->request->get['filter'])) {
			$filter = $this->request->get['filter'];
		} else {
			$filter = '';
		}

		if (isset($this->request->get['sort'])) {
			$sort = $this->request->get['sort'];
		} else {
			$sort = 'p.sort_order';
		}

		if (isset($this->request->get['order'])) {
			$order = $this->request->get['order'];
		} else {
			$order = 'ASC';
		}

		if (isset($this->request->get['page'])) {
			$page = $this->request->get['page'];
		} else {
			$page = 1;
		}

		if (isset($this->request->get['limit'])) {
			$limit = (int)$this->request->get['limit'];
		} else {
			$limit = $this->config->get('config_product_limit');
		}

		$data['breadcrumbs'] = array();

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('text_home'),
			'href' => $this->url->link('common/home')
		);

		if (isset($this->request->get['path'])) {
			$url = '';

			if (isset($this->request->get['sort'])) {
				$url .= '&sort=' . $this->request->get['sort'];
			}

			if (isset($this->request->get['order'])) {
				$url .= '&order=' . $this->request->get['order'];
			}

			if (isset($this->request->get['limit'])) {
				$url .= '&limit=' . $this->request->get['limit'];
			}

			$path = '';

			$parts = explode('_', (string)$this->request->get['path']);

			$category_id = (int)array_pop($parts);

			foreach ($parts as $path_id) {
				if (!$path) {
					$path = (int)$path_id;
				} else {
					$path .= '_' . (int)$path_id;
				}

				$category_info = $this->model_catalog_category->getCategory($path_id);

				if ($category_info) {
					$data['breadcrumbs'][] = array(
						'text' => $category_info['name'],
						'href' => $this->url->link('product/category', 'path=' . $path . $url)
					);
				}
			}
		} else {
			$category_id = 0;
		}

		$category_info = $this->model_catalog_category->getCategory($category_id);

		if ($category_info) {
			$this->document->setTitle($category_info['meta_title']);
			$this->document->setDescription($category_info['meta_description']);
			$this->document->setKeywords($category_info['meta_keyword']);


			
			$data['text_special_start'] = $this->language->get('text_special_start');
			$data['text_special_end'] = $this->language->get('text_special_end');
			
			
			$data['heading_title'] = $category_info['name'];

			$data['text_refine'] = $this->language->get('text_refine');
			$data['text_empty'] = $this->language->get('text_empty');
			$data['text_quantity'] = $this->language->get('text_quantity');
			$data['text_manufacturer'] = $this->language->get('text_manufacturer');
			$data['text_model'] = $this->language->get('text_model');
			$data['text_price'] = $this->language->get('text_price');
			$data['text_tax'] = $this->language->get('text_tax');
			$data['text_points'] = $this->language->get('text_points');
			$data['text_compare'] = sprintf($this->language->get('text_compare'), (isset($this->session->data['compare']) ? count($this->session->data['compare']) : 0));
			$data['text_sort'] = $this->language->get('text_sort');
			$data['text_limit'] = $this->language->get('text_limit');

			$data['button_cart'] = $this->language->get('button_cart');
			$data['button_wishlist'] = $this->language->get('button_wishlist');
			$data['button_compare'] = $this->language->get('button_compare');
			$data['button_continue'] = $this->language->get('button_continue');
			$data['button_list'] = $this->language->get('button_list');
			$data['button_grid'] = $this->language->get('button_grid');

			// Set the last category breadcrumb
			$data['breadcrumbs'][] = array(
				'text' => $category_info['name'],
				'href' => $this->url->link('product/category', 'path=' . $this->request->get['path'])
			);

			if ($category_info['image']) {
				$data['thumb'] = $this->model_tool_image->resize($category_info['image'], $this->config->get('config_image_category_width'), $this->config->get('config_image_category_height'));
			} else {
				$data['thumb'] = '';
			}

			$data['description'] = html_entity_decode($category_info['description'], ENT_QUOTES, 'UTF-8');
			$data['compare'] = $this->url->link('product/compare');

			$url = '';

			if (isset($this->request->get['filter'])) {
				$url .= '&filter=' . $this->request->get['filter'];
			}

			if (isset($this->request->get['sort'])) {
				$url .= '&sort=' . $this->request->get['sort'];
			}

			if (isset($this->request->get['order'])) {
				$url .= '&order=' . $this->request->get['order'];
			}

			if (isset($this->request->get['limit'])) {
				$url .= '&limit=' . $this->request->get['limit'];
			}

			$data['categories'] = array();

			$results = $this->model_catalog_category->getCategories($category_id);

			foreach ($results as $result) {
				$filter_data = array(
					'filter_category_id'  => $result['category_id'],
					'filter_sub_category' => true
				);


                $categories[] = array(
                    'name'      => $result['name'],
                    'image'     => $result['image'] ? $this->model_tool_image->resize($result['image'], $this->config->get('config_image_category_width'), $this->config->get('config_image_category_height')) : '',
                    'image_raw' => $result['image'],
                    'desc'      => html_entity_decode($result['meta_description'], ENT_QUOTES, 'UTF-8'),
                    'href'      => $this->url->link('product/category', 'path=' . $this->request->get['path'] . '_' . $result['category_id'] . $url)
                );
            
				$data['categories'][] = array(
					'name' => $result['name'] . ($this->config->get('config_product_count') ? ' (' . $this->model_catalog_product->getTotalProducts($filter_data) . ')' : ''),
					'href' => $this->url->link('product/category', 'path=' . $this->request->get['path'] . '_' . $result['category_id'] . $url)
				);
			}


                $data['categories'] = !empty($categories) ? $categories : $data['categories'];
            
			$data['products'] = array();

			$filter_data = array(
				'filter_category_id' => $category_id,
				'filter_filter'      => $filter,
				'sort'               => $sort,
				'order'              => $order,
				'start'              => ($page - 1) * $limit,
				'limit'              => $limit
			);

			$product_total = $this->model_catalog_product->getTotalProducts($filter_data);

			$results = $this->model_catalog_product->getProducts($filter_data);

			$data['lowpricenotify_outofstock_install_status'] =  $this->config->get('lowpricenotify_outofstock_install_status');
			$data['lowpricenotify_button_text_color'] = $this->config->get('lowpricenotify_button_text_color');
			$data['lowpricenotify_button_background_color'] = $this->config->get('lowpricenotify_button_background_color');

			foreach ($results as $result) {
				if ($result['image']) {
					
			if ($this->config->get('config_watermark_status') == 1 && $this->config->get('config_watermark_image') != null) {
				$store_id = $this->config->get('config_store_id');

				$image = $this->model_tool_image->resizeOcbwatermark($result['image'], $this->config->get('config_image_product_width'), $this->config->get('config_image_product_height'), '$store_id/');
			} else {
				$image = $this->model_tool_image->resize($result['image'], $this->config->get('config_image_product_width'), $this->config->get('config_image_product_height'));
			}
			
//BUPS
                                        //print_r($result);
                                        if (isset($this->request->server['HTTPS']) && (($this->request->server['HTTPS'] == 'on') || ($this->request->server['HTTPS'] == '1'))) {
                                            $http = $this->config->get('config_ssl') . 'image/';
                                        } else {
                                            $http = $this->config->get('config_url') . 'image/';
                                        }
                                        if (isset($this->request->get['store_id'])) {
                                            $store_id = $this->request->get['store_id'];
                                        } else {
                                            $store_id = 0;
                                        }
                                        $this->load->model('setting/setting');
                                        $settings = $this->model_setting_setting->getSetting('labelimage', $store_id);
                                        if ($settings['labelimage_status']=='1'){
                                            if ($result['topleft_png'] || $result['topright_png'] || $result['bottomleft_png'] || $result['bottomright_png']){
                                                $this->load->model('tool/labelimage');
                                                
                                                $image = $this->model_tool_labelimage->setLabelImage($image, $result['topleft_png'], $result['topright_png'], $result['bottomleft_png'], $result['bottomright_png'],$http,$result['image'],$result['product_id'], $this->config->get('config_image_product_width'), $this->config->get('config_image_product_height'), $settings['labelimage_productexpros'], $settings['labelimage_autoresize']);
                                            }
                                        }
                                        //end

				
				} else {
					$image = $this->model_tool_image->resize('placeholder.png', $this->config->get('config_image_product_width'), $this->config->get('config_image_product_height'));
				}

				if (($this->config->get('config_customer_price') && $this->customer->isLogged()) || !$this->config->get('config_customer_price')) {
					$price = $this->currency->format($this->tax->calculate($result['price'], $result['tax_class_id'], $this->config->get('config_tax')));
				} else {
					$price = false;
				}

				if ((float)$result['special']) {
					$special = $this->currency->format($this->tax->calculate($result['special'], $result['tax_class_id'], $this->config->get('config_tax')));
				} else {
					$special = false;
				}

				if ($this->config->get('config_tax')) {
					$tax = $this->currency->format((float)$result['special'] ? $result['special'] : $result['price']);
				} else {
					$tax = false;
				}

				if ($this->config->get('config_review_status')) {
					$rating = (int)$result['rating'];
				} else {
					$rating = false;
				}

				if ($result['quantity'] <= 0) {
					$stock_status = ($result['quantity'] == 0)?$this->language->get('Out Of Stock'):$result['stock_status'];
				} elseif ($this->config->get('config_stock_display')) {
					$stock_status = $result['quantity'];
				} else {
					$stock_status = $this->language->get('In Stock');
				}
			
            $button_stock = $result['quantity'] <= 0 ? $result['stock_status'] : $data['button_cart'];
            

			
			$dates = $this->model_catalog_product->getProductSpecialDates($result['product_id']);
			
			if ($this->config->get('config_special_start') && isset($dates['start']) && ($dates['start'] != "0000-00-00")) {
				$special_start = date($this->language->get('date_format_short'), strtotime($dates['start']));
			} else {
				$special_start = "";
			}
			
			if ($this->config->get('config_special_end') && isset($dates['end']) && ($dates['end'] != "0000-00-00")) {
				$special_end = date($this->language->get('date_format_short'), strtotime($dates['end']));
			} else {
				$special_end = "";
			}
			
			
            $data['products'][] = array(

			
			'special_start' => $special_start,
			'special_end' => $special_end,
			
			
                'contact_block'  => $result['quantity'],
                'button_stock'  => $button_stock,
            
						'stock'       => $stock_status,
					'product_id'  => $result['product_id'],
					'thumb'       => $image,
					'name'        => $result['name'],
					'description' => utf8_substr(strip_tags(html_entity_decode($result['description'], ENT_QUOTES, 'UTF-8')), 0, $this->config->get('config_product_description_length')) . '..',
					'price'       => $price,
					'special'     => $special,
					'tax'         => $tax,
					'minimum'     => $result['minimum'] > 0 ? $result['minimum'] : 1,
					'rating'      => $result['rating'],
					'href'        => $this->url->link('product/product', 'path=' . $this->request->get['path'] . '&product_id=' . $result['product_id'] . $url)
				);
			}

			$url = '';

			if (isset($this->request->get['filter'])) {
				$url .= '&filter=' . $this->request->get['filter'];
			}

			if (isset($this->request->get['limit'])) {
				$url .= '&limit=' . $this->request->get['limit'];
			}

			$data['sorts'] = array();

			$data['sorts'][] = array(
				'text'  => $this->language->get('text_default'),
				'value' => 'p.date_added-DESC',
				'href'  => $this->url->link('product/category', 'path=' . $this->request->get['path'] . '&sort=p.date_added&order=DESC' . $url)
			);

			$data['sorts'][] = array(
				'text'  => $this->language->get('text_name_asc'),
				'value' => 'pd.name-ASC',
				'href'  => $this->url->link('product/category', 'path=' . $this->request->get['path'] . '&sort=pd.name&order=ASC' . $url)
			);

			$data['sorts'][] = array(
				'text'  => $this->language->get('text_name_desc'),
				'value' => 'pd.name-DESC',
				'href'  => $this->url->link('product/category', 'path=' . $this->request->get['path'] . '&sort=pd.name&order=DESC' . $url)
			);

			$data['sorts'][] = array(
				'text'  => $this->language->get('text_price_asc'),
				'value' => 'p.price-ASC',
				'href'  => $this->url->link('product/category', 'path=' . $this->request->get['path'] . '&sort=p.price&order=ASC' . $url)
			);

			$data['sorts'][] = array(
				'text'  => $this->language->get('text_price_desc'),
				'value' => 'p.price-DESC',
				'href'  => $this->url->link('product/category', 'path=' . $this->request->get['path'] . '&sort=p.price&order=DESC' . $url)
			);

			if ($this->config->get('config_review_status')) {
				$data['sorts'][] = array(
					'text'  => $this->language->get('text_rating_desc'),
					'value' => 'rating-DESC',
					'href'  => $this->url->link('product/category', 'path=' . $this->request->get['path'] . '&sort=rating&order=DESC' . $url)
				);

				$data['sorts'][] = array(
					'text'  => $this->language->get('text_rating_asc'),
					'value' => 'rating-ASC',
					'href'  => $this->url->link('product/category', 'path=' . $this->request->get['path'] . '&sort=rating&order=ASC' . $url)
				);
			}

			$data['sorts'][] = array(
				'text'  => $this->language->get('text_model_asc'),
				'value' => 'p.model-ASC',
				'href'  => $this->url->link('product/category', 'path=' . $this->request->get['path'] . '&sort=p.model&order=ASC' . $url)
			);

			$data['sorts'][] = array(
				'text'  => $this->language->get('text_model_desc'),
				'value' => 'p.model-DESC',
				'href'  => $this->url->link('product/category', 'path=' . $this->request->get['path'] . '&sort=p.model&order=DESC' . $url)
			);

			$url = '';

			if (isset($this->request->get['filter'])) {
				$url .= '&filter=' . $this->request->get['filter'];
			}

			if (isset($this->request->get['sort'])) {
				$url .= '&sort=' . $this->request->get['sort'];
			}

			if (isset($this->request->get['order'])) {
				$url .= '&order=' . $this->request->get['order'];
			}

			$data['limits'] = array();

			$limits = array_unique(array($this->config->get('config_product_limit'), 25, 50, 75, 100));

			sort($limits);

			foreach($limits as $value) {
				$data['limits'][] = array(
					'text'  => $value,
					'value' => $value,
					'href'  => $this->url->link('product/category', 'path=' . $this->request->get['path'] . $url . '&limit=' . $value)
				);
			}

			$url = '';

			if (isset($this->request->get['filter'])) {
				$url .= '&filter=' . $this->request->get['filter'];
			}

			if (isset($this->request->get['sort'])) {
				$url .= '&sort=' . $this->request->get['sort'];
			}

			if (isset($this->request->get['order'])) {
				$url .= '&order=' . $this->request->get['order'];
			}

			if (isset($this->request->get['limit'])) {
				$url .= '&limit=' . $this->request->get['limit'];
			}

			$pagination = new Pagination();
			$pagination->total = $product_total;
			$pagination->page = $page;
			$pagination->limit = $limit;
			$pagination->url = $this->url->link('product/category', 'path=' . $this->request->get['path'] . $url . '&page={page}');

			$data['pagination'] = $pagination->render();

			$data['results'] = sprintf($this->language->get('text_pagination'), ($product_total) ? (($page - 1) * $limit) + 1 : 0, ((($page - 1) * $limit) > ($product_total - $limit)) ? $product_total : ((($page - 1) * $limit) + $limit), $product_total, ceil($product_total / $limit));

			// http://googlewebmastercentral.blogspot.com/2011/09/pagination-with-relnext-and-relprev.html
			if ($page == 1) {
			    $this->document->addLink($this->url->link('product/category', 'path=' . $category_info['category_id'], 'SSL'), 'canonical');
			} elseif ($page == 2) {
			    $this->document->addLink($this->url->link('product/category', 'path=' . $category_info['category_id'], 'SSL'), 'prev');
			} else {
			    $this->document->addLink($this->url->link('product/category', 'path=' . $category_info['category_id'] . '&page='. ($page - 1), 'SSL'), 'prev');
			}

			if ($limit && ceil($product_total / $limit) > $page) {
			    $this->document->addLink($this->url->link('product/category', 'path=' . $category_info['category_id'] . '&page='. ($page + 1), 'SSL'), 'next');
			}

			$data['sort'] = $sort;
			$data['order'] = $order;
			$data['limit'] = $limit;

			$data['continue'] = $this->url->link('common/home');

			$data['column_left'] = $this->load->controller('common/column_left');
			$data['column_right'] = $this->load->controller('common/column_right');
			$data['content_top'] = $this->load->controller('common/content_top');
			$data['content_bottom'] = $this->load->controller('common/content_bottom');

                if ($this->config->get('config_template') == 'default2') {
                    $data['default2']   = $this->config->get('default2');

                    $this->load->model('extension/default2');

                    $blockToLoad = array('top_a', 'top_b', 'top_c', 'bottom_a', 'bottom_b', 'bottom_c');
                    $data += $this->model_extension_default2->getAllPosition($blockToLoad);
                    $data['footer'] = $this->load->controller('common/footer');
                    $data['header'] = $this->load->controller('common/header');
                    
                    $data['description'] = (strip_tags($data['description']) != '') ? $data['description'] : '';

                    $templates          = array();
                    $template_category  = $data['default2']['template_category'];
                    $template_options   = array_diff(array(1, 2), array($template_category));

                    foreach ($template_options as $opt) {
                        if (isset($data['default2']['template_category_specific_' . $opt])) {
                            $templates = array_map('trim', explode(',', $data['default2']['template_category_specific_' . $opt]));
                            if (in_array($category_id, $templates)) {
                                $template_category = $opt;
                                break;
                            }
                        }
                    }

                    if ($template_category == '2') {
                        $data['categories'] = array();
                        foreach ($categories as $i => $category) {
                            $data['categories'][$i] = $category;
                            $data['categories'][$i]['image'] = $category['image_raw'];
                            $data['categories'][$i]['image'] = $category['image_raw'] ? $this->model_tool_image->resize($category['image_raw'], $data['default2']['child_thumb_size_width'], $data['default2']['child_thumb_size_height']) : '';
                        }
                    }

                    $default2_template  = 'category_d2_' . $template_category;
                    if (file_exists(DIR_TEMPLATE . $this->config->get('config_template') . '/template/product/' . $default2_template . '.tpl')) {
                        return $this->response->setOutput($this->load->view($this->config->get('config_template') . '/template/product/' . $default2_template . '.tpl', $data));
                    }
                }
            
			$data['footer'] = $this->load->controller('common/footer');
			$data['header'] = $this->load->controller('common/header');

			if (file_exists(DIR_TEMPLATE . $this->config->get('config_template') . '/template/product/category.tpl')) {
				$this->response->setOutput($this->load->view($this->config->get('config_template') . '/template/product/category.tpl', $data));
			} else {
				$this->response->setOutput($this->load->view('default/template/product/category.tpl', $data));
			}
		} else {
			$url = '';

			if (isset($this->request->get['path'])) {
				$url .= '&path=' . $this->request->get['path'];
			}

			if (isset($this->request->get['filter'])) {
				$url .= '&filter=' . $this->request->get['filter'];
			}

			if (isset($this->request->get['sort'])) {
				$url .= '&sort=' . $this->request->get['sort'];
			}

			if (isset($this->request->get['order'])) {
				$url .= '&order=' . $this->request->get['order'];
			}

			if (isset($this->request->get['page'])) {
				$url .= '&page=' . $this->request->get['page'];
			}

			if (isset($this->request->get['limit'])) {
				$url .= '&limit=' . $this->request->get['limit'];
			}

			$data['breadcrumbs'][] = array(
				'text' => $this->language->get('text_error'),
				'href' => $this->url->link('product/category', $url)
			);

			$this->document->setTitle($this->language->get('text_error'));


			
			$data['text_special_start'] = $this->language->get('text_special_start');
			$data['text_special_end'] = $this->language->get('text_special_end');
			
			
			$data['heading_title'] = $this->language->get('text_error');

			$data['text_error'] = $this->language->get('text_error');

			$data['button_continue'] = $this->language->get('button_continue');

			$data['continue'] = $this->url->link('common/home');

			$this->response->addHeader($this->request->server['SERVER_PROTOCOL'] . ' 404 Not Found');

			$data['column_left'] = $this->load->controller('common/column_left');
			$data['column_right'] = $this->load->controller('common/column_right');
			$data['content_top'] = $this->load->controller('common/content_top');
			$data['content_bottom'] = $this->load->controller('common/content_bottom');

                if ($this->config->get('config_template') == 'default2') {
                    $data['default2']   = $this->config->get('default2');

                    $this->load->model('extension/default2');

                    $blockToLoad = array('top_a', 'top_b', 'top_c', 'bottom_a', 'bottom_b', 'bottom_c');
                    $data += $this->model_extension_default2->getAllPosition($blockToLoad);
                    $data['footer'] = $this->load->controller('common/footer');
                    $data['header'] = $this->load->controller('common/header');
                    
                    $data['description'] = (strip_tags($data['description']) != '') ? $data['description'] : '';

                    $templates          = array();
                    $template_category  = $data['default2']['template_category'];
                    $template_options   = array_diff(array(1, 2), array($template_category));

                    foreach ($template_options as $opt) {
                        if (isset($data['default2']['template_category_specific_' . $opt])) {
                            $templates = array_map('trim', explode(',', $data['default2']['template_category_specific_' . $opt]));
                            if (in_array($category_id, $templates)) {
                                $template_category = $opt;
                                break;
                            }
                        }
                    }

                    if ($template_category == '2') {
                        $data['categories'] = array();
                        foreach ($categories as $i => $category) {
                            $data['categories'][$i] = $category;
                            $data['categories'][$i]['image'] = $category['image_raw'];
                            $data['categories'][$i]['image'] = $category['image_raw'] ? $this->model_tool_image->resize($category['image_raw'], $data['default2']['child_thumb_size_width'], $data['default2']['child_thumb_size_height']) : '';
                        }
                    }

                    $default2_template  = 'category_d2_' . $template_category;
                    if (file_exists(DIR_TEMPLATE . $this->config->get('config_template') . '/template/product/' . $default2_template . '.tpl')) {
                        return $this->response->setOutput($this->load->view($this->config->get('config_template') . '/template/product/' . $default2_template . '.tpl', $data));
                    }
                }
            
			$data['footer'] = $this->load->controller('common/footer');
			$data['header'] = $this->load->controller('common/header');

			if (file_exists(DIR_TEMPLATE . $this->config->get('config_template') . '/template/error/not_found.tpl')) {
				$this->response->setOutput($this->load->view($this->config->get('config_template') . '/template/error/not_found.tpl', $data));
			} else {
				$this->response->setOutput($this->load->view('default/template/error/not_found.tpl', $data));
			}
		}
	}
}
